#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <inttypes.h>

#include "cli.h"
#include "cli_nodes.h"
#include "frontend_nodes.h"

int cli_getnodes(struct backend_conn * conn, int argc, char ** argv) {
	size_t num_nodes = 0;
	struct frontend_node_data * node_data;

	int needHelp = 0;
	
	if ((needHelp = help_check(argc, argv))) {
		printf("getnodes gets the number of nodes along with the block_id, type_id and name of each node\n");
		printf("Usage Syntax : \n\t./Cli getnodes\n");
		printf("Symlink Usage Syntax : \n\t./getnodes\n\n");
		return 0;
	}

	if (argc > 1) {
		printf("Incorrect Usage, run './cli getnodes --help' for correct usage.\n");
		return 1;
	}

	node_data = malloc(sizeof(*node_data) * num_nodes);

	if (frontend_getnodes(conn, node_data, &num_nodes)) {
		free(node_data);
		return 1;
	}

	printf("unimplemented\n");
	free(node_data);
	return 0;
}

int cli_addnode(struct backend_conn * conn, int argc, char ** argv) {
	struct frontend_node_data node_data;
	int needHelp = 0;
	
	if ((needHelp = help_check(argc, argv))) {
		printf("addnodes adds a node of specified type_id and name to the comp_graph\n");
		printf("Usage Syntax : \n\t./Cli addnode type_id name\n");
		printf("Symlink Usage Syntax : \n\t./addnode type_id name\n\n");
		return 0;
	}

	if (argc < 3) {
		printf("Incorrect Usage, run './cli addnode --help' for correct usage.\n");
		return 1;
	}
	
	node_data.type = atoi(argv[1]);
	strncpy(node_data.name, argv[2], 512/* this value matches the max space of name */ );

	if (frontend_addnode(conn, &node_data)) {
		return 1;
	}

	printf("Node created with block_id : %" PRId16 "\n", node_data.block);
	return 0;
}
